/**
 * easyWSDL - easyWSDL toolbox Platform.
 * Copyright (c) 2008,  eBM Websourcing
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the University of California, Berkeley nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE REGENTS AND CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.ow2.easywsdl.wsdl.decorator;

import java.util.List;
import java.util.Map;

import javax.xml.namespace.QName;

import org.ow2.easywsdl.schema.api.Documentation;
import org.ow2.easywsdl.schema.api.XmlException;
import org.ow2.easywsdl.schema.api.absItf.AbsItfImport;
import org.ow2.easywsdl.schema.api.absItf.AbsItfSchema;
import org.ow2.easywsdl.schema.api.abstractElmt.AbstractSchemaElementImpl;
import org.ow2.easywsdl.wsdl.api.WSDLElement;
import org.ow2.easywsdl.wsdl.api.WSDLException;
import org.ow2.easywsdl.wsdl.api.abstractElmt.AbstractWSDLElementImpl;
import org.ow2.easywsdl.wsdl.api.abstractItf.AbsItfTypes;
import org.w3c.dom.Element;


/**
 * @author Nicolas Salatge - eBM WebSourcing
 */
@SuppressWarnings("unchecked")
public class DecoratorTypesImpl<S extends AbsItfSchema, Impt extends AbsItfImport> extends AbstractWSDLElementImpl implements Decorator {

    /**
	 *
	 */
    private static final long serialVersionUID = 1L;

    protected AbsItfTypes<S, Impt> types;

    public DecoratorTypesImpl(final AbsItfTypes<S, Impt> types) throws WSDLException {
        this.types = types;
    }

    public List<S> getSchemas() {
        return this.types.getSchemas();
    }

    public List<Impt> getImportedSchemas() {
        return this.types.getImportedSchemas();
    }

    public Documentation createDocumentation() {
        return this.types.createDocumentation();
    }

    public Documentation getDocumentation() {
        return this.types.getDocumentation();
    }

    public Map<QName, String> getOtherAttributes() throws XmlException {
        return this.types.getOtherAttributes();
    }

    public List<Element> getOtherElements() throws XmlException {
        return this.types.getOtherElements();
    }

    public void setDocumentation(final Documentation arg0) {
        this.types.setDocumentation(arg0);
    }

	public void addSchema(S schema) {
		this.types.addSchema(schema);
	}

	public S createSchema() {
		return this.types.createSchema();
	}

	public S removeSchema() {
		return this.types.removeSchema();
	}

    @Override
	public Object getModel() {
		return ((AbstractWSDLElementImpl)this.types).getModel();
	}

    @Override
	public AbstractSchemaElementImpl getParent() {
		return ((AbstractWSDLElementImpl)this.types).getParent();
	}

	public WSDLElement getInternalObject() {
		return this.types;
	}
}
